from synctera_client.paths.cards_images_card_image_id_data.get import ApiForget
from synctera_client.paths.cards_images_card_image_id_data.post import ApiForpost


class CardsImagesCardImageIdData(
    ApiForget,
    ApiForpost,
):
    pass
