from synctera_client.paths.monitoring_subscriptions_subscription_id.get import ApiForget
from synctera_client.paths.monitoring_subscriptions_subscription_id.delete import ApiFordelete


class MonitoringSubscriptionsSubscriptionId(
    ApiForget,
    ApiFordelete,
):
    pass
