from synctera_client.paths.persons_personal_ids_personal_id_id.delete import ApiFordelete
from synctera_client.paths.persons_personal_ids_personal_id_id.patch import ApiForpatch


class PersonsPersonalIdsPersonalIdId(
    ApiFordelete,
    ApiForpatch,
):
    pass
