from synctera_client.paths.cards_gateways_gateway_id.get import ApiForget
from synctera_client.paths.cards_gateways_gateway_id.patch import ApiForpatch


class CardsGatewaysGatewayId(
    ApiForget,
    ApiForpatch,
):
    pass
