# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.37.0
    Generated by: https://openapi-generator.tech
"""

from synctera_client.paths.accounts.post import CreateAccount
from synctera_client.paths.accounts_account_id_relationships.post import CreateAccountRelationship
from synctera_client.paths.accounts_products.post import CreateAccountResourceProduct
from synctera_client.paths.accounts_templates.post import CreateAccountTemplate
from synctera_client.paths.accounts_account_id_relationships_relationship_id.delete import DeleteAccountRelationship
from synctera_client.paths.accounts_templates_template_id.delete import DeleteAccountTemplate
from synctera_client.paths.accounts_account_id.get import GetAccount
from synctera_client.paths.accounts_account_id_relationships_relationship_id.get import GetAccountRelationship
from synctera_client.paths.accounts_templates_template_id.get import GetAccountTemplate
from synctera_client.paths.accounts_account_id_relationships.get import ListAccountRelationship
from synctera_client.paths.accounts_products.get import ListAccountResourceProducts
from synctera_client.paths.accounts_templates.get import ListAccountTemplates
from synctera_client.paths.accounts.get import ListAccounts
from synctera_client.paths.accounts_account_id.patch import PatchAccount
from synctera_client.paths.accounts_products_product_id.patch import PatchAccountProduct
from synctera_client.paths.accounts_account_id.put import UpdateAccount
from synctera_client.paths.accounts_account_id_relationships_relationship_id.put import UpdateAccountRelationship
from synctera_client.paths.accounts_templates_template_id.put import UpdateAccountTemplate


class AccountsApi(
    CreateAccount,
    CreateAccountRelationship,
    CreateAccountResourceProduct,
    CreateAccountTemplate,
    DeleteAccountRelationship,
    DeleteAccountTemplate,
    GetAccount,
    GetAccountRelationship,
    GetAccountTemplate,
    ListAccountRelationship,
    ListAccountResourceProducts,
    ListAccountTemplates,
    ListAccounts,
    PatchAccount,
    PatchAccountProduct,
    UpdateAccount,
    UpdateAccountRelationship,
    UpdateAccountTemplate,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
