from synctera_client.paths.persons_person_id.get import ApiForget
from synctera_client.paths.persons_person_id.patch import ApiForpatch


class PersonsPersonId(
    ApiForget,
    ApiForpatch,
):
    pass
