# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.37.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class Shipping(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Details about the shipping method. If supplied this will override the default shipping address of the customer or account.
    """


    class MetaOapg:
        
        class properties:
        
            @staticmethod
            def address() -> typing.Type['Address1']:
                return Address1
            care_of_line = schemas.StrSchema
            is_expedited_fulfillment = schemas.BoolSchema
            
            
            class method(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def LOCAL_MAIL(cls):
                    return cls("LOCAL_MAIL")
                
                @schemas.classproperty
                def TWO_DAY(cls):
                    return cls("TWO_DAY")
                
                @schemas.classproperty
                def OVERNIGHT(cls):
                    return cls("OVERNIGHT")
                
                @schemas.classproperty
                def INTERNATIONAL(cls):
                    return cls("INTERNATIONAL")
            
            
            class phone_number(
                schemas.StrSchema
            ):
                pass
        
            @staticmethod
            def recipient_name() -> typing.Type['RecipientName']:
                return RecipientName
            __annotations__ = {
                "address": address,
                "care_of_line": care_of_line,
                "is_expedited_fulfillment": is_expedited_fulfillment,
                "method": method,
                "phone_number": phone_number,
                "recipient_name": recipient_name,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["address"]) -> 'Address1': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["care_of_line"]) -> MetaOapg.properties.care_of_line: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_expedited_fulfillment"]) -> MetaOapg.properties.is_expedited_fulfillment: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["method"]) -> MetaOapg.properties.method: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["phone_number"]) -> MetaOapg.properties.phone_number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["recipient_name"]) -> 'RecipientName': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["address", "care_of_line", "is_expedited_fulfillment", "method", "phone_number", "recipient_name", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["address"]) -> typing.Union['Address1', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["care_of_line"]) -> typing.Union[MetaOapg.properties.care_of_line, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_expedited_fulfillment"]) -> typing.Union[MetaOapg.properties.is_expedited_fulfillment, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["method"]) -> typing.Union[MetaOapg.properties.method, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["phone_number"]) -> typing.Union[MetaOapg.properties.phone_number, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["recipient_name"]) -> typing.Union['RecipientName', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["address", "care_of_line", "is_expedited_fulfillment", "method", "phone_number", "recipient_name", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        address: typing.Union['Address1', schemas.Unset] = schemas.unset,
        care_of_line: typing.Union[MetaOapg.properties.care_of_line, str, schemas.Unset] = schemas.unset,
        is_expedited_fulfillment: typing.Union[MetaOapg.properties.is_expedited_fulfillment, bool, schemas.Unset] = schemas.unset,
        method: typing.Union[MetaOapg.properties.method, str, schemas.Unset] = schemas.unset,
        phone_number: typing.Union[MetaOapg.properties.phone_number, str, schemas.Unset] = schemas.unset,
        recipient_name: typing.Union['RecipientName', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Shipping':
        return super().__new__(
            cls,
            *_args,
            address=address,
            care_of_line=care_of_line,
            is_expedited_fulfillment=is_expedited_fulfillment,
            method=method,
            phone_number=phone_number,
            recipient_name=recipient_name,
            _configuration=_configuration,
            **kwargs,
        )

from synctera_client.model.address1 import Address1
from synctera_client.model.recipient_name import RecipientName
