from synctera_client.paths.customers_customer_id_verifications.get import ApiForget
from synctera_client.paths.customers_customer_id_verifications.post import ApiForpost


class CustomersCustomerIdVerifications(
    ApiForget,
    ApiForpost,
):
    pass
