from synctera_client.paths.payment_schedules.get import ApiForget
from synctera_client.paths.payment_schedules.post import ApiForpost


class PaymentSchedules(
    ApiForget,
    ApiForpost,
):
    pass
