from synctera_client.paths.cards_digital_wallet_tokens_digital_wallet_token_id.get import ApiForget
from synctera_client.paths.cards_digital_wallet_tokens_digital_wallet_token_id.patch import ApiForpatch


class CardsDigitalWalletTokensDigitalWalletTokenId(
    ApiForget,
    ApiForpatch,
):
    pass
