from synctera_client.paths.customers_customer_id_employment.get import ApiForget
from synctera_client.paths.customers_customer_id_employment.post import ApiForpost


class CustomersCustomerIdEmployment(
    ApiForget,
    ApiForpost,
):
    pass
