from synctera_client.paths.documents_document_id.get import ApiForget
from synctera_client.paths.documents_document_id.patch import ApiForpatch


class DocumentsDocumentId(
    ApiForget,
    ApiForpatch,
):
    pass
