# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.37.0
    Generated by: https://openapi-generator.tech
"""

from synctera_client.paths.persons.post import CreatePerson
from synctera_client.paths.persons_personal_ids.post import CreatePersonalId
from synctera_client.paths.persons_personal_ids_personal_id_id.delete import DeletePersonalId
from synctera_client.paths.persons_person_id.get import GetPerson
from synctera_client.paths.persons.get import ListPersons
from synctera_client.paths.persons_person_id_prefill.post import PrefillPerson
from synctera_client.paths.persons_person_id.patch import UpdatePerson
from synctera_client.paths.persons_personal_ids_personal_id_id.patch import UpdatePersonalId


class PersonsApi(
    CreatePerson,
    CreatePersonalId,
    DeletePersonalId,
    GetPerson,
    ListPersons,
    PrefillPerson,
    UpdatePerson,
    UpdatePersonalId,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
