from synctera_client.paths.internal_accounts.get import ApiForget
from synctera_client.paths.internal_accounts.post import ApiForpost


class InternalAccounts(
    ApiForget,
    ApiForpost,
):
    pass
