# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.37.0
    Generated by: https://openapi-generator.tech
"""

from synctera_client.paths.customers_customer_id_watchlists_alerts_alert_id.get import GetWatchlistAlert
from synctera_client.paths.customers_customer_id_watchlists_subscriptions_subscription_id.get import GetWatchlistSubscription
from synctera_client.paths.customers_customer_id_watchlists_alerts.get import ListWatchlistAlerts
from synctera_client.paths.customers_customer_id_watchlists_subscriptions.get import ListWatchlistSubscriptions
from synctera_client.paths.customers_customer_id_watchlists_suppressions.post import SuppressWatchlistEntityAlert
from synctera_client.paths.customers_customer_id_watchlists_alerts_alert_id.put import UpdateWatchlistAlert
from synctera_client.paths.customers_customer_id_watchlists_subscriptions_subscription_id.put import UpdateWatchlistSubscription
from synctera_client.paths.customers_customer_id_watchlists_subscriptions.post import WatchlistSubscribe


class WatchlistDeprecatedApi(
    GetWatchlistAlert,
    GetWatchlistSubscription,
    ListWatchlistAlerts,
    ListWatchlistSubscriptions,
    SuppressWatchlistEntityAlert,
    UpdateWatchlistAlert,
    UpdateWatchlistSubscription,
    WatchlistSubscribe,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
